function [dec, typ] = osdec(s,mrads)
% OSDEC gets decenter and tilt data from OSLO
% function [dec, typ] = osdec(s,mrads)
% This function returns the decenter and tilt values for surfaces s
%   INPUT:  s, default = 1:imsnbr
%           mrads: if nonzero, output is converted to meters/radians
% 
%     See also osrbset, osshift, osrbshift, osprb.


if nargin<1, s = 1:osnum; end
if nargin<2, mrads = 0; end %default is to NOT to convert to meters/radians output
    
oscmd('sbr; for(i=1;i<imsnbr+1;i++) aprt dcx[i] dcy[i] dcz[i] tla[i] tlb[i] tlc[i] tox[i] toy[i] toz[i];');
dec = osssb(1:osnum,1:9);
dec = dec(s,:);

if mrads %convert lens units to meters/radians
    uni = osuni;
    dec(:,1:3) = dec(:,1:3)*uni/1e3;
    dec(:,4:6) = dec(:,4:6)*pi/180;
    dec(:,7:9) = dec(:,7:9)*uni/1e3;
end

if nargout>1
    if osreq(['ben[' int2str(s(i)) '];]'])==1; typ{i} = 'ben';
    elseif osreq(['rco[' int2str(s(i)) '];]'])==1; typ{i} = 'rco';
    else typ{i} = 'std';
    end
    typ = typ{s};
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
