function [RMSval,PVval] = osfig(data,mask)
% OSFIG general purpose 2d plotter for the OSLO toolkit
%   function [RMSval,PVval] = osfig(data,mask)
%   input:  data
%           mask is optional
%   output: RMSval = std dev of data (masked if included)
%           PVval = Peak to valley of data (masked if included)

if nargin<1, 
    scrsz = get(0,'ScreenSize');
    figure('Position',[scrsz(3)/4 scrsz(4)/4 0.6*scrsz(3) 0.6*scrsz(4)]);
    return
end;

if ~isreal(data), data = real(data); end;

if size(data,1) == 1 || size(data,2) == 1
    sqrtval = sqrt(length(data));
    if mod(length(data), fix(sqrtval)) == 0
        data = reshape(data,sqrtval,sqrtval);
    end
end
        
if nargin<2
% figure, imagesc(data), colorbar, axis square;
    mask = ~isnan(data) & data~=0;
end

if nargin>0
    scrsz = get(0,'ScreenSize');
    figure('Position',[scrsz(3)/4 scrsz(4)/4 0.6*scrsz(3) 0.6*scrsz(4)]);
    plotdata = data.*mask;
    nodata = find(mask==0);
    plotdata(nodata)=NaN;
    imagesc(plotdata), axis image, axis xy, colorbar;
        set(gca,'XTick',[]); set(gca,'YTick',[]); set(gca,'ZTick',[])
    title(inputname(1));
    [RMSval,PVval,maxval,minval,meanval] = stats(plotdata,mask);
    xlabel({['AVG = ' num2str(meanval)];['RMS = ' num2str(RMSval)];['PV =  ' num2str(PVval)]});    
end

%===================================================================
function [stdval,pk2val,maxval,minval,meanval,p95] = stats(data,mask)
%  Reports statistics on data, filtered by mask (if input)

if nargin<1, help stats; return, end

if nargin<2
    mask = ~isnan(data) & data~=0;
    datavals = data(mask);
else
    datavals = data(mask);
end

stdval = std(data(mask));
maxval = max(datavals);
minval = min(datavals);
pk2val = maxval-minval;
meanval = mean(datavals);

p95 = sort(datavals);
p95 = p95(ceil(.95*length(datavals)));


