function [fl] = osfl(f,w)
% OSFL returns focal length
% function [fl] = osfl(f)
%   INPUT:  f = field points (default = 1)
%           w = wavelength number (default = 0)
%   OUTPUT: fl = focal length in lens units

if nargin<1, f=1; end; % ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
if nargin<2, w=0; end; % current wavelength

[scale,ftyp] = osftyp;
if ftyp~=1, disp('OSLO lens is not defined with field angles. Aborting.'); return, end

fp = osf(); %get all defined fields
fx0 = fp(f,1); %choose desired fields
fy0 = fp(f,2); %choose desired fields
dang = 1e-9; %change in angle for calculation, 1 nr
dang_deg = dang*180/pi; %change in angle for calculation, 1 nr

for i=1:length(fx0)
    % trace base ray and differential rays
    xy(1,:) = ossop( [fx0(i) fy0(i)]          , w, 0 );
    xy(2,:) = ossop( [fx0(i) fy0(i)+dang_deg] , w, 0 );
    xy(3,:) = ossop( [fx0(i) fy0(i)-dang_deg] , w, 0 );
    xy(4,:) = ossop( [fx0(i)-dang_deg fy0(i)] , w, 0 );
    xy(5,:) = ossop( [fx0(i)+dang_deg fy0(i)] , w, 0 );
    % find mean deviation of differential rays
    for j=1:4
        dxy(j) = sqrt( sum( (xy(j+1,:)-xy(1,:)).^2 ) );
    end
    meandxy = mean(dxy);
    % evaluate focal length based on input angle change
    fl(i) = meandxy/tan(dang);
end
fl = fl';

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
