function data = osfov(gridsize,fieldsize,option)
% OSFOV gets field performance wavefront data from OSLO
% function data = osfov(gridsize,fieldsize,option)
% xfov and yfov are full fields of view centered about 0,0
% xgrid and ygrid are gridsize to sample fov
% option: 1 = Minimum along image surface, 2 = Best focus, 3 = Reference ray 

if nargin<1, gridsize = 11; end
if nargin<2, fieldsize = osftyp; end %normalized field value set in OSLO
if nargin<3, option = 1; end %rms wfe

step = fieldsize/(gridsize-1);
data = zeros(gridsize);

tic
for i=1:gridsize
    fx = -fieldsize/2.0 + step*(i-1);
    for j=1:gridsize
        fy = -fieldsize/2.0 + step*(j-1);
        ossop([fx fy],0,0); %absolute field coordinate requested
        if option ==1, data(i,j) = oswvf; end
    end
end
toc
data = data';

if nargout<1
    figure; imagesc(data); colorbar; axis image;
    xlabel(['Field size = ' num2str(fieldsize)]);
    if option==1, title('RMS WFE over field'); end
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
