function [gc, gcs] = osgc(s,gcs)
% OSGC gets global coordinate data, and sets surfaces to global
% function [gc, gcs] = osgc(s,gcs)
%   INPUT:  s = surfaces (default = 1:imsnbr)
%           NOTE: negative s input sets global coords for s to gcs
%           gcs = global coordinate system reference, 
%                 default = value set in OSLO
%   OUTPUT: gc = global coordinates in lens units
%           gcs = global coordinate reference surface

if nargin<1, s = 1:osnum; end
if nargin<2, gcs = osreq('+gcs'); end

if nargin>1, oscmd(['gcs ' int2str(gcs)]); end

if sum( s<0 ) > 1, %negative sign sets surfaces s to global coords
    [temp,index] = sort( abs(s(:)) ,1,'descend');
    for i=1:length(s)
        if s(index(i)) < 0 %set only negative s values
            if -s(index(i)) > gcs
                oscmd(['gc ' int2str([-s(index(i)) gcs])]);
            else
                disp('Refsurf must be < surface number to convert !  Please check input!');
            end
        end
    end
end

%get global coord data
oscmd('sbr; pe_global_coordinates;');
gc = osssb(abs(s),1:6);

if nargout<0
    disp(['Reference surface = ' int2str(gcs) ]);
    gc = num2str(gc);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
