function [opd, mask, rmsval, xshift, yshift, zshift] = osgwf(gridsize, ref_option, w, xref, yref, zref)
% OSGWF gets the wavefront map for the current fieldpoint in OSLO
% function [opd, mask, rmsval, xshift, yshift, zshift] 
%    = osgwf(gridsize,ref_option, w, xref, yref, zref)
% INPUT:
%       gridsize = size of wavefront grid (default = 100), must be even
%       ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
%       w:  defined wavelength number, 0 = current (default = 0)
%       x,y,z ref shift:  offset of ref ray (valid only with ref_option 2) (default = 0)
% OUTPUT:
%       all units are converted to m
%       if nargout<1, wavefront map will be plotted

if nargin < 1, gridsize = 100; end;
if nargin < 2, ref_option = 0; end;             % 0 = min rms, 1 = best focus, 2 = ref ray
if nargin < 3, w = 0; end;             % 0 = current wavelength
if nargin < 4, xref=0; end;
if nargin < 5, yref=0; end;
if nargin < 6, zref=0; end;

if gridsize~=even(gridsize)
    gridsize=even(gridsize);
    disp('Warning! OSLO generates only EVEN grid wavefronts');
    disp(['Gridsize has been changed to ' num2str(gridsize)]);
end

% set shift values
if ref_option~=2, cmd = 'arg4=arg5=arg6=0;';
else cmd = ['arg4= ' num2str(xref) ';arg5= ' num2str(yref) ';arg6= ' num2str(zref) ';'];
end
oscmd(cmd); % disp(cmd);

if gridsize<300
    % execute and transfer gwf data through DDE
    oscmd(['stp umxs 0 ' int2str(gridsize) '; for(i=0;i<int_pref(umxs,0);i++) for(j=0;j<int_pref(umxs,0);j++) mx0[i][j] = 0;']); %set user matrix in oslo to gridsize
    % OSLO: cmd get_wavefront_data(Gwf_ref_option, Gwf_wavelength, Gwf_lines, a=Gwf_opdmin, b=Gwf_opdmax, c=Gwf_rmsopd, d=Gwf_xshift, e=Gwf_yshift, f=Gwf_zshift, gwfmat=Gwf_data)
    cmd = ['opdw off; gwf(' int2str(ref_option) ',' int2str(w) ',' int2str(gridsize) ', &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &Mx0);'];
    oscmd(cmd,gridsize);%use gridsize to set waiting time
    [opd,mask] = osmx();
    % opd = OSLOmx0(1:gridsize);
    % mask = opd~=1e20;
else
    % write and read bin file from gwf ouput in OSLO... THIS NEEDS WORK
    cmd = ['stp umxs 0 ' int2str(gridsize) ';opdw off; gwf(' int2str(ref_option)...
        ',' int2str(w) ',' int2str(gridsize) ', &arg1, &arg2, &arg3, &arg4, &arg5, &arg6, &Mx0);'...
        'ii = fopen("./mx0.bin",w); fwrite(ii, mx0); fclose(ii);'];
    oscmd(cmd);
    fid = fopen('mx0.bin','r');
    while fid==-1, fid = fopen('mx0.bin','r'); end        
    opd = fread(fid,gridsize*gridsize,'double');
    fclose(fid);
    delete 'mx0.bin';
    opd = reshape(opd,gridsize,gridsize);
    mask = opd~=1e20;
    opd(mask) = 0;
end

% flip data ud to match OSLO output
opd = flipud(opd); mask = flipud(mask);
opd = mask.*opd*(osuni/1e3); % convert opd to meters

if nargout > 2,
    units2m = osuni/1e3;
    opdrms = ddereq(OSLO,['arg3'] )*units2m;
    xshift = ddereq(OSLO,['arg4'] )*units2m;
    yshift = ddereq(OSLO,['arg5'] )*units2m;
    zshift = ddereq(OSLO,['arg6'] )*units2m;
end

if nargout<1, osfig(opd,mask); end

%========================================
%========================================
function even = even(number)
% function even = even(number)
%   Returns the closest even integer smaller than or equal to the input
if nargin<1, even=0; return, end
even = floor(number);
if mod(even,2)==1, %case where even is odd
    even=even-1;
end
%========================================
%========================================

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
