function [data,mask] = osint(intfilename,s,fid,scale,radius,decxy,rotangle,mirrorxy)
%OSINT  gets and/or attaches an INT file to surface in OSLO
%	function [data,mask] =
%	      osint(intfilename,s,fid,scale,radius,decxy,rotangle,mirrorxy)
%
%   INPUTS: intfilename = name of INT file to be read/written in current directory
%               NOTE: the function will prompt you to choose a file if
%               blank
%           s = surface on which to apply INT file
%           fid = int file id, seperate number for each file on surface,
%                 default = 0
%           radius = 
%
%   OUTPUT: data = when reading an INT file, returns numeric data
%           mask = array of zeros and ones corresponding to actual data
%
%   See also:  loadint, makeint

if nargin<2, help osint; end
if isempty(intfilename)  %get file via gui if nothing entered
    [filename,pathname] = uigetfile({'*.int',  'int Files (*.int)'},'Pick an .int file');
    intfilename = [pathname filename];
else 
    [pathname,a,b]=fileparts(intfilename);
    filename = [a b];
end

if nargin>1 %assign int file to surface in OSLO
    if nargin<3, fid = 0; end
    %load int file command
    if length(pathname>0), 
        cmd = ['stp itfd "' cd '";']
    else
        cmd = [];
    end
    cmd = [cmd 'itf ' int2str(s) ' "' filename '" ' int2str(fid) ';']; %set int file directory and load int file
    oscmd(cmd);
    
    %additional optional settings for int file
    cmd = [];
    if nargin>3, cmd = [cmd 'its ' int2str(s) ' ' num2str(scale) ' ' int2str(fid) ';']; end %scale
    if nargin>4, cmd = [cmd 'itr ' int2str(s) ' ' num2str(radius) ' ' int2str(fid) ';']; end %radius
    if nargin>5, 
        cmd = [cmd 'itx ' int2str(s) ' ' num2str(decxy(1)) ' ' int2str(fid) ';']; %x decenter
        cmd = [cmd 'ity ' int2str(s) ' ' num2str(decxy(2)) ' ' int2str(fid) ';']; %y decenter
    end
    if nargin>6, %rotation angle, must be:   -180< rotangle < 180
        while rotangle<-180, rotangle = rotangle + 360; end
        while rotangle> 180, rotangle = rotangle - 360; end
        cmd = [cmd 'ita ' int2str(s) ' ' num2str(rotangle) ' ' int2str(fid) ';']; 
    end 
    oscmd(cmd);
else
    return
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
