function its = osits(s,scale,d_yn)
% OSITS gets and sets interferogram scale data from OSLO
% function its = osits(s,scale,d_yn)
%   INPUT:  s, surfaces (default = 1:imsnbr)
%           scale, values to set surface int data to (default = 1);
%           d_yn, perturbation from existing value (default = 0, no);
%   OUTPUT: its = vector containing scale data, prior to setting data
% 
%     See also osint

if nargin<1, s = 1:osnum; end %get all int scale data from each surface
if nargin<2, scale = s.*0+1; end %default to set scale to equal 1.0
if nargin<3, d_yn = 0; end %default to int number 0

while length(scale)<length(s)
    scale = [scale(:); 1];
end

oscmd('sbr; for(i=1;i<imsnbr+1;i++) aprt its[i][0];');
its = osssb(1:osnum,1);
its = its(s);

if nargin>1 %set scale data
    if d_yn==0
        for i=1:length(s)
           oscmd(['its ' int2str(s(i)) ' ' num2str(scale(i)) ' 0;']);
        end
    else %perturb scale data from existing value
        for i=1:length(s)
           oscmd(['its ' int2str(s(i)) ' its[' int2str(s(i)) '][0]+' num2str(scale(i)) ' 0;']);
        end
    end
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
