function [data,mask] = osmx(mxnum,i)
% OSMX gets data from user matrices in OSLO
% function [data,mask] = osmx(mxnum,i)
%   INPUT:  mxnum = matrix id number: 0,1 or 2 (default = 0)
%           i = desired row index of data retrieval (default = all) 
%           NOTE:  Unlike Matlab, OSLO matrix data indices begin with 0
%   OUTPUT:  data = square matrix of size i
%            mask  = logical matrix will give 0 values for 1e20 data values (i.e. rayfailures)

if nargin<1, mxnum = 0; end
if nargin<2, i = 0:osreq(['int_pref(umxs,' int2str(mxnum) ')' ])-1; end

OSLO_globaldata = ddeinit('oslodde','GlobalData'); %open dedicated link for faster retrieval of large amounts of data
for ic=1:length(i)
        data(ic,:) = ddereq(OSLO_globaldata,['mx0[' int2str(i(ic)) '];'] ); %gets entire row of data
end
ddeterm(OSLO_globaldata);

if nargout>1 | nargout==0, mask = data~=1e20; end

if nargout<1, 
    figure, imagesc(data.*mask)
    title('OSLO mx0')
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
