function osprb(surfnum,pdata,units)
% OSPRB applies rigid body perturbations to surfaces in OSLO 
% function osprb(surfnum,pdata,units)
% INPUT:    
%   pdata = [dx dy dz da db dc]
%           units = 0, no conversion (i.e. lens units assumed)  default = 0
%                 = 1, assumes m / rad input, converts to lens units
%   NOTE:  OSLO tilt perturbations are in euler angle convention, 
%        where da and db are left handed tilts
% 
%	See also osshift, osrbshift, osdec.

if nargin<2, help osprb, return, end;
if nargin<3, units=0; end;

if units==1
    pdata(:,1:3) = pdata(:,1:3)*1e3/osuni; %converts input m to lens units
    pdata(:,4:6) = pdata(:,4:6)*180/pi; %convert rad to deg
end

r = size(pdata,1);
for i=1:r
    surfstr = int2str(surfnum(i));
    cmd = [ 'dcx(' surfstr ',dcx[' surfstr ']+' num2str(pdata(i,1),15) ');dcy(' surfstr ',dcy[' surfstr ']+' num2str(pdata(i,2),15) ');dcz(' surfstr ',dcz[' surfstr ']+' num2str(pdata(i,3),15) ');' ];
    cmd = [cmd 'tla(' surfstr ',tla[' surfstr ']+' num2str(pdata(i,4),15) ');tlb(' surfstr ',tlb[' surfstr ']+' num2str(pdata(i,5),15) ');tlc(' surfstr ',tlc[' surfstr ']+' num2str(pdata(i,6),15) ');' ];
    oscmd(cmd);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
