function psf = ospsf(gridsize,imagesize,rs_ref,mon_chr,focusshift,timeout)
% OSPSF gets psf data from OSLO
% function psf = ospsf(gridsize,imagesize,rs_ref,mon_chr,focusshift,timeout)
%  INPUT:
%     gridsize = number of rows and columns (square), default = 63
%     imagesize = side of square in image space (in lens units), default
%     rs_ref option: 0 if min rms wavefront error (default), 1 reference ray, 2 centroid
%     mon_chr option: 0 if monochromatic (current wv) (default), 1 if polychromatic 
%  OUTPUT:
%     psf values normalized to system with no wavefront error, peak value =
%     strehl ratio of lens

tic

if nargin<1, gridsize = 63; end
if nargin<2, imagesize = 10*osreq('Airyrad'); end
if nargin<3, rs_ref = 0; end
if nargin<4, mon_chr = 0; end
if nargin<5, focusshift = 0; end
if ~exist('timeout'), timeout=gridsize/2, end

cmd = 'sfg xy ';
if mon_chr==0, cmd = [cmd ' mon 0 ']; else cmd = [cmd 'chr ']; end
cmd = [cmd num2str(imagesize) ' ' int2str(gridsize) ' ' num2str(focusshift)]
oscmd(cmd,timeout); %add timeout for extensive calculations
oscmd(['stp umxs 0 ' int2str(gridsize) ';gpsa(&mx0,&i,&j)']); %put sfg data into mat128 buffer
psf = osmx(0);

if nargout<1,
    figure, imagesc(psf)
    xlabel(['Image size = ' num2str(imagesize)]),
    title({'Direct integration PSF';['Pupil sampling = ' int2str(osgd('sdad'))]});
end

toc

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
