function [raydata] = osray(f,r,s,w,c,gc)
% OSRAY gets ray trace data from OSLO
% function [raydata] = osray(f,r,s,w,c,gc);
% inputs:   f = field number(s), default = 1, 0 = all
%           r = ray number(s), default = 1, 0 = all
%           s = surface(s), default = image surface, 0 = all
%           w = wavelength(s), default = 1, 0 = all
%           c = configuration, default = 1, 0 = all
%           gc = 0 local coords, 1 = global coords (default = 0, local)
% output:  Vector containing x y z k l m opl
%          Vectors are built into a matrix in nested order: c w s f r

% Y,X,Z,Yang,Xang,D,L,K,M,AOI,AOR,OPL,Surf

[nums,numf,numw,numc,numr] = osnum;

if nargin<1, if numf<1,disp('No fields defined!'); return; else f=1; end; end; %default fp 1
if nargin<2, if numr<1,disp('No rays defined!'); return; else r=1; end; end; %default to center of pupil
if nargin<3, s=nums; end;
if nargin<4, w=1; end;
if nargin<5, c=1; end;
if nargin<6, gc=0; end;

if f==0, f=1:numf; end
if r==0, r=1:osreq('raynbr-1'); end
if s==0, s=1:nums; end
if w==0, w=1:numw; end
if c==0, c=1:numc; end
    
raydata = [];
for i_c = 1:length(c)
    osc(c(i_c));
    for i_w = 1:length(w)
        for i_s = 1:length(s)
            for i_f = 1:length(f)
                ossop( f(i_f) ); %set field coordinate
                for i_r = 1:length(r)

                    % Build command
                    %tra  ful loc Srf r 2 4 4 y 3
                    %tra  ful loc Srf usr 1 3 4 4 y 3
                    if gc==0, cmd = 'sbr; tra ful loc srf ';
                    else cmd = 'sbr; tra ful glo srf ';
                    end
                    % ray type
                    if length(r(i_r))==2, cmd = [cmd 'usr ' num2str( r(i_r,1:2) ) ' y '];
                    else cmd = [cmd 'r ' int2str( r(i_r) ) ' '];
                    end
                    cmd = [cmd int2str( s(i_s) ) ' ' int2str( s(i_s) ) ' y ' int2str( w(i_w) )];
                    oscmd(cmd);

                    rayvals = osssb(1,[2 1 3]); rayvals = [rayvals osssb(2,[2 1 3 6])]; % x y z K L M OPL
                    if rayvals==0, if osreq('sbrow')<2, rayvals = rayvals*NaN; end; end
                    %rayvals = OSLOssb(1:2,1:7); %y/x/z/yang/xang/d/surface/l/k/m/iang/rang/opl
                    %rearrange raytrace data to: y/x/z/yang/xang/d/surface/l/k/m/iang/rang/opl
                    raydata = [raydata rayvals(:)];
                end
            end
        end
    end
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
