function osrbset(s,DOFnum,setval,mrads)
% OSRBSET sets the coordinates of a surface in OSLO
% function osrbset(s,DOFnum,setval,mrads)
%   INPUT:  s, default = 1:imsnbr
%           DOFnums (1-6) = dcx, dcy, dcz, tla, tlb, tlc respectively
%           setval, values to set
%           mrads: if nonzero, input is assumed to be meters/radians
%                  default = 0, assumes lens units (e.g. mm), and degrees

if nargin<1, help osrbset, return; end
if nargin<2, DOFnum=1; end
if nargin<3, setval = 0.0; end 
if nargin<4, mrads = 0; end %default is to NOT assume meters/radians input

% stack up DOFnum and shiftval to equal same length of surfnum
while length(DOFnum)<length(s), DOFnum = [DOFnum DOFnum(end)]; end
while length(setval)<length(s), setval = [setval setval(end)]; end

if mrads %convert meters/radians input to lens units
    uni = osuni;
    for i=1:length(s)
        if DOFnum(i)<4, setval(i) = setval(i)*1e3/uni;
        else setval(i) = setval(i)*180/pi;
        end
    end
end

for i=1:length(s)
    if DOFnum==1, DOF = 'dcx';
    elseif DOFnum==2, DOF = 'dcy';
    elseif DOFnum==3, DOF = 'dcz';
    elseif DOFnum==4, DOF = 'tla';
    elseif DOFnum==5, DOF = 'tlb';
    elseif DOFnum==6, DOF = 'tlc';
    else return;
    end
    cmd = [ DOF '( ' num2str(s) ', ' num2str(setval,20) ');' ];
    oscmd(cmd);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
