function osrbshift(s,DOFnum,shiftval,mrads)
% OSRBSHIFT "shifts" a surface relative to its current position in OSLO
% function osrbshift(s,DOFnum,shiftval,mrads)
%  INPUT:   s = surface
%           DOFnums (1-6) = dcx, dcy, dcz, tla, tlb, tlc respectively
%           shiftval UNITS: lens units (e.g. mm), and degrees
%           mrads: if nonzero, input is interpreted as meters/radian input
% 
%     See also osshift, osprb, osdec.


if nargin<1, help osrbshift, return; end
if nargin<2, DOFnum = ones(length(s),1); end %default to x-shift
if nargin<3, shiftval = ones(length(s),1)*1e-3; end %micron/milli-degree default
if nargin<4, mrads = 0; end %default is to NOT assume meters/radians input

% stack up DOFnum and shiftval to equal same length of surfnum
while length(DOFnum)<length(s), DOFnum = [DOFnum DOFnum(end)]; end
while length(shiftval)<length(s), shiftval = [shiftval shiftval(end)]; end
if mrads
    uni = osuni;
    for i=1:length(s)
        if DOFnum(i)<4, shiftval(i) = shiftval(i)*uni*1e3;
        else shiftval(i) = shiftval(i)*180/pi;
        end
    end
end

for i=1:length(s)
    if DOFnum(i) == 1, DOF = 'dcx';
    elseif DOFnum(i) == 2, DOF = 'dcy';
    elseif DOFnum(i) == 3, DOF = 'dcz';
    elseif DOFnum(i) == 4, DOF = 'tla';
    elseif DOFnum(i) == 5, DOF = 'tlb';
    elseif DOFnum(i) == 6, DOF = 'tlc';
    elseif DOFnum(i) == 7, DOF = 'tox';
    elseif DOFnum(i) == 8, DOF = 'toy';
    elseif DOFnum(i) == 9, DOF = 'toz';
    else return;
    end
    sn = num2str( s(i) );
    cmd = [ DOF '( ' sn ', ' DOF '[' sn '] + ' num2str(shiftval(i),20) ');' ];
    oscmd(cmd);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
