function output = osreq(cmd,timeout,string_yn)
% OSREQ executes command and requests output data from OSLO
% function output = osreq(cmd,timeout)
% This function provides for direct execution of OSLO commands from Matlab
%   INPUT:  cmd is an OSLO command line text string
%           timeout (in seconds) should be used if OSLO requires > 3 seconds to perform a task
%           string_yn = 0 for numeric data, 1 for string (default = 0)
%   OUTPUT:  is currently assumed to be a number.
%            If text is desired, use osreqstr

if nargin<1, output=0; return; end
if nargin<2, timeout=3.0; end
if nargin<3, string_yn = 0; end

OSLO = ddeinit('oslodde','OSLO_Command');

if string_yn==0,
    output = ddereq(OSLO,cmd, [1 0], timeout*1000); %numeric output
else
    output = ddereq(OSLO,cmd, [1 1], timeout*1000); %string output
end

ddeterm(OSLO);

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
