function osshift(s,dcx,dcy,dcz,tla,tlb,tlc,mrads)
% OSSHIFT "shifts" a surface in rigid body relative to its current position
% function osshift(s,dcx,dcy,dcz,tla,tlb,tlc,mrads)      7 args
%          osshift( [s dcx dcy dcz tla tlb tlc],mrads)   2 args
%          osshift( s,[dcx dcy dcz tla tlb tlc],mrads)   3 args

if nargin<1, help osshift, return, end

if size(s,2)==7 %matrix input in arg 1, surf and DOF
    dcx = s(:,2); dcy = s(:,3); dcz = s(:,4); 
    tla = s(:,5); tlb = s(:,6); tlc = s(:,7);
    s = s(:,1);
    if nargin<2, mrads = 0; else mrads = dcx(1); end
elseif size(dcx,2)==6 %matrix input in arg 2, DOF
    dcy = dcx(:,2); dcz = dcx(:,3); 
    tla = dcx(:,4); tlb = dcx(:,5); tlc = dcx(:,6);  
    dcx = dcx(:,1);
    if nargin<3, mrads = 0; else mrads = dcy(1); end
elseif nargin<7, disp('Need more data;'), help osshift, return 
elseif nargin<8, mrads = 0; 
end
    
if mrads %converts input meters/radians to lens units
    uni = osuni;
    dcx = dcx*1e3/uni; dcy = dcy*1e3/uni; dcz = dcz*1e3/uni;
    tla = tla*180/pi; tlb = tlb*180/pi; tlc = tlc*180/pi;
end

numsurfs = length(s(:));
for i=1:numsurfs
    sn = num2str(s(i));
    cmd = [ 'dcx( ' sn ', dcx[' sn '] + ' num2str(dcx(i),20) ');dcy( ' sn ', dcy[' sn '] + ' num2str(dcy(i),20) ');dcz( ' sn ', dcz[' sn '] + ' num2str(dcz(i),20) ');' ];
    oscmd(cmd);
    cmd = [ 'tla( ' sn ', tla[' sn '] + ' num2str(tla(i),20) ');tlb( ' sn ', tlb[' sn '] + ' num2str(tlb(i),20) ');tlc( ' sn ', tlc[' sn '] + ' num2str(tlc(i),20) ');' ];
    oscmd(cmd);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
