function [surfacenotes, objectnote] = ossn(s, withnumbers_yn)
% OSSN gets the surface notes from OSLO
% function [surfacenotes, objectlabel] = ossn(s, withnumbers_yn)
%   INPUT:	s, default = 1:imsnbr
%           withnumbers_yn = logic to add surface number prior to label
%                            default = 1 (yes)
%   OUTPUT: surfacenotes = notes or labels on each surface
%           objectnote = note on object

if nargin<1, s = 1:osnum; end
if nargin<2, withnumbers_yn = 1; end % default to put numbers in front of label data

surfacenotes = [];
for i=1:length(s)
    oscmd(['get_surface_note(' int2str(s(i)) '); sprintf(astr,surface_note);']);
    label = osgd('astr',1); 
    if length(label)<1, label = ' '; end
    if withnumbers_yn
        surfacenotes = strvcat(surfacenotes,[int2str(s(i)) ' ' label]);
    else
        surfacenotes = strvcat(surfacenotes,label);
    end
end

if nargout~=1
    oscmd(['get_surface_note(0); sprintf(astr,surface_note);']);
    objectnote = osgd('astr',1);
    if withnumbers_yn, objectnote = ['0 ' objectnote]; end
end

if nargout<1 && nargin<1
    surfacenotes = strvcat(objectnote,surfacenotes);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
