function [xy,fxyz,refrad,opl] = ossop(f,w,norm_yn)
% OSSOP sets the object point in OSLO
% function [xy,fxyz,refrad,opl] = ossop(f,w,norm_yn)
% input:    f = field number (scalar input), OR
%               [fbx fby fbz fxrf fyrf], or portion thereof, where
%                   fbx, fby, fbz = normalized field coords 
%                   fyrf, fxrf = normalized pupil coords
%           w = wavelength number, only works when length(f)==1
%           norm_yn = 1 if input is already normalized to max field (default) 
%                   = 0 if input is absolute (deg/lens units) and needs
%                     needs to be normalized
% output:   xc, yc = reference ray coords at image
%           fbx fby fbz = x y z object coordinates

if nargin<1, f=1; end
if nargin<2, w=0; end
if nargin<3, norm_yn = 1; end

if ~norm_yn && length(f)>1
   f = f/osftyp; %scale field data by +ang or +obh
end

cmd = 'sbr; sop';
if nargin>0, 
    if length(f)==1, cmd = [cmd ' f ' int2str(f)];
    elseif length(f)>1,
        fnew = [f(2) f(1)]; %fbx fby input
        if length(f)>2, fnew = [fnew f(3)]; end %fbx fby fbz input
        if length(f)>4, fnew = [fnew f(5) f(4)]; end %fbx fby fbz fxrf fyrf input
        cmd = [cmd ' ' num2str(fnew,18)];
%         for i=1:length(f), cmd = [cmd ' ' num2str(fnew(i))]; end
    end
    if nargin==2 && length(f)==1, cmd = [cmd ' ' int2str(w(1))]; end
end

oscmd(cmd);

xy = osssb(3,[2 1]);

if nargout>1
    fxyz = osssb(1,1:3);
    refrad = osssb(3,6);
    opl = osssb(3,5);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
