function [fbx,fby,fbz] = ossopfi(x,y,f,cent_yn)
% OSSOPFI sets object point based on image coordinate using sopfi function
% function [fbx,fby,fbz] = ossopfi(x,y,f,cent_yn)
% sets the desired field point in OSLO
% input:    x,y = positions on image surface to target
%                 ALT input: x = [x y] 
%           f = field number to set
%           cent_yn = use centroid if ~=0 
% output:   fbx fby fbz = x y z object coordinates

if nargin<1, x=0; end
if nargin<2, y=0; end
if nargin<3, f=osnumf+1; end
if nargin<4, cent_yn = 0; end

if length(x)>1, y=x(2); x=x(1); end

cmd = ['sbr; sopfi ' num2str([y x f cent_yn]) ];
oscmd(cmd);

if nargout>0
    fscale = osftyp;
    data = osssb(2,1:3);
    fby = data(1)*fscale;
    fbx = data(2)*fscale;
    fbz = data(3)*fscale;
    if nargout==1, fbx = [fbx fby fbz]; end
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
