function [rmsR,rmsXY,difflimit,XYcent] = ossps(focus_option,focus_shift)
% OSSPS returns spot size data from OSLO
% function [rmsR,rmsXY,rmsY,difflimit,Xcent,Ycent] = ossps(focus_option,focus_shift)
%   INPUT:  focus_option:   0 = no option (default), manual focus_shift
%                           1 = best focus for minimum radius
%                           2 = best focus for minimum X
%                           3 = best focus for minimum Y
%           focus_shift:  value of focus shift to apply (default = 0)
%   OUTPUT: rmsR = rms spot radius (lens units)
%           rmsXY = rms spot size in X and Y (lens units)
%           difflimit = diffration limited spot radius
%           XYcent = relative motion of spot centroid from chief ray 

if nargin<1, focus_option=0; end; % ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
if nargin<2, focus_shift=0; end; 

if focus_option==0
    oscmd(['sbr; sps none ' num2str(focus_shift)]);
elseif focus_option==1
    oscmd('sbr; sps bfr;');
elseif focus_option==2
    oscmd('sbr; sps bfx;');
elseif focus_option==3
    oscmd('sbr; sps bfy;');
end

data = osssb(1,1:6);
rmsR = data(1);
rmsXY = data(2:3);
difflimit = data(4);
XYcent = data(5:6);

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
