function varargout = ostra(f,r,s,w,c,gc)
% OSTRA gets ray trace data from OSLO
% function [raydata] = ostra(f,r,s,w,c,gc);
% Gets ray trace data from OSLO
% inputs:   f = field number, default = 1
%           r = ray number, default = 1
%           s = surface, default = image surface
%           w = wavelength number, default = 1
%           c = configuration, default = 1
%           gc = 0 local coords, 1 = global coords (default = 0, local)
% output:  Vector containing X,Y,Z,K,L,M,OPL,Xang,Yang,AOI,AOR,D,Surf
%          Vectors are built into a matrix in same order as input:  f r s w c

% Author:  Joseph M. Howard
% OSLO version 6.4

[nums,numf,numw,numc,numr] = osnum;
if numf<1, disp('No fields defined! Aborting command.'); return, end
if numr<1, disp('No rays defined! Aborting command.'); return, end
    
if nargin<1, f=1; end; %default fp 1
if nargin<2, r=1; end; %default ray 1
if nargin<3, s=nums; end;
if nargin<4, w=1; end;
if nargin<5, c=1; end;
if nargin<6, gc=0; end;

for i_f=1:length(f)
    ossop( f(i_f) );
    for i_r=1:length(r)
        for i_s=1:length(s)
            for i_w=1:length(w)
                osw( w(i_w) );
                for i_c=1:length(c)
                    c0 = osc( c(i_c) );

                    % Build command
                    raydata = [];
                    if gc==0, cmd = 'sbr; tra ful loc srf ';
                    else cmd = 'sbr; tra ful glo srf ';
                    end
                    % ray type 
                    if size(r,2)==2, cmd = [cmd 'usr ' num2str( [ r(i_r,1) r(i_r,2)] ) ' ']; %tra ful loc srf usr  1 2 14 14 y 1
                    else cmd = [cmd 'r ' int2str( r(i_r) ) ' ']; %tra ful loc srf  r 1 14 14 y 1
                    end
                    cmd = [cmd int2str( s(i_s) ) ' ' int2str( s(i_s) ) ' y ' int2str( w(i_w) )]
                    oscmd(cmd);

                    rayvals = osssb(1:2,1:7);  %y/x/z/yang/xang/d/surface/l/k/m/iang/rang/opl
                    rayvals = rayvals([3 1 5 4 2 6 12 9 7 8 10 11 13]); %X,Y,Z,K,L,M,OPL,Xang,Yang,AOI,AOR,D,Surf
                    %rayvals = osssb(1,[2 1 3]); rayvals = [rayvals osssb(2,[2 1 3 6])]; % x y z K L M OPL
                    raydata(:,i_f,i_r,i_s,i_w,i_c) = rayvals;
                    
                end
            end
        end
    end
end

if nargout>1
    for i=nargout:-1:1
        varargout{i} = squeeze(raydata(i,:,:,:,:));
    end
elseif nargout==1
    varargout{1} = squeeze(raydata);
else
    x = raydata(1,:,:,:,:); x = x(:);
    y = raydata(2,:,:,:,:); y = y(:);
    figure, scatter(x,y,'.');
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
