function [w0,ww0] = osw(w,ww)
% OSW gets and sets wavelength data in OSLO
%  function [w,ww] = osw(wv,ww)
%   INPUTS: w = wavelength number or value
%           ww = wavelength weight
%   OUTPUT: w0 = current wavelengths (in microns)
%           ww0 = current wavelength weights

for i=1:osnumw
    w0(i) = osreq(['wv[' int2str(i) ']']);
    ww0(i) = osreq(['ww[' int2str(i) ']']);
end    
    
if nargin>0
    %set wavelength number
    if length(w)==1 && w(1)<= osnumw && w(1)>0 
        oscmd(['setw ' int2str(w(1))]); 
    %OR set new wavelengths and weights
    else 
        cmd = ['wv ' num2str(w(1))];
            for i=2:length(w), cmd = [cmd ' ' num2str(w(i))]; end
        oscmd(cmd);
        if nargin>1
           if length(ww)<length(w), ww(length(ww)+1:length(w)) = 1.0; end %fill in missing weights
           cmd = ['ww ' num2str(ww(1))];
                for i=2:length(w), cmd = [cmd ' ' num2str(ww(i))]; end
           oscmd(cmd);
        end
    end
end

if nargout<1 && nargin<1
    disp('Current Wavelengths in OSLO');
    fprintf('#\tmicrons\t\tweight\n');
    for i=1:length(w0)
        fprintf('%d\t%f\t%f\n',i,w0(i),ww0(i));
    end
    clear w0
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
