function [rmswvf,pk2val,strehl,dx,dy,dz] = oswvf(ref_option,w,xyz)
% OSWVF returns wavefront error data
% function [rmswvf,pk2val,strehl,dx,dy,dz] = oswvf(ref_option,w,xyz)
%   INPUT:  ref_option:  0 = min rms (default), 1 = best focus, 2 = ref ray 
%                        3 = none, (min rms with xyz shift)
%           w:  0 = current wavelength, 1..max defined wavelength number (default = 0)
%           xyz:  shift of reference sphere
%                 ref_option 0, z focus shift only
%                 ref_option 1, not used
%                 ref_option 2, x y z shift
%                 ref_option 3, x y z shift           
%   OUTPUT: rmswvf = rms wavefront error (lens units)
%           pk2val = peak 2 valley error (lens units)
%           strehl
%           dx dy dz = relative motion of PSF from chief ray 
if nargin<1, ref_option=0; end; % ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
if nargin<2, w=0; end; 
if nargin<3, xyz = [0 0 0]; end

if ref_option==0
    oscmd(['sbr; opdw off; wvf rs ' int2str(w) ' ' num2str(xyz(1))]);
elseif ref_option==1
    oscmd(['sbr; opdw off; wvf bf ' int2str(w)]);
elseif ref_option==2
    oscmd(['sbr; opdw off; wvf ref ' int2str(w) ' ' num2str(xyz(2)) ' ' num2str(xyz(1)) ' ' num2str(xyz(3)) ]);
else
    oscmd(['sbr; opdw off; wvf ' int2str(w) ' ' num2str(xyz(2)) ' ' num2str(xyz(1)) ' ' num2str(xyz(3))]);
end

data = osssb(1,1:6);
pk2val = data(1);
rmswvf = data(2);
strehl = data(3);

if nargout>3 %shift data of psf
    dx = data(5);
    dy = data(4);
    dz = data(6);
end

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
