function [zervals,rmsval,errorval] = oszer(numzer,ref_option,w,x,y,z)
% OSZER returns fringe zernike data from OSLO
% function [zer,rms,error] = oszer(numzer,ref_option,w,x,y,z)
%   INPUT:  numzer = number of zernikes desired (Fringe Zernike ordering)
%           ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
%           w:  0 = current wavelength, 1..max defined wavelength number (default = 0)
%           x,y,z ref shift:  valid only with ref_option 2, offset of ref ray
%   OUTPUT: zervals = zernike coefficient data
%           rmsval = rms opd
%           errorval = fitting error of zernike fit

if nargin<1, numzer = 1:37; end
if nargin<2, ref_option=0; end; % ref_option:  0 = min rms, 1 = best focus, 2 = ref ray (default = 0)
if nargin<3, w=0; end; 
if nargin<4, x=0; y=0; z=0; end

if ref_option==0
    oscmd(['sbr; opdw off; zer rs ' int2str(w)]);
elseif ref_option==1
    oscmd(['sbr; opdw off; zer bf ' int2str(w)]);
elseif ref_option==2
    oscmd(['sbr; opdw off; zer ref ' int2str(w) ' ' num2str(x) ' ' num2str(y) ' ' num2str(z) ]);
end

zervals = osssb(1:37,1);
zervals = zervals(numzer);
data = osssb(38,1:2);
rmsval = data(1);
errorval = data(2);

% Copyright  2004-2005 United States Government as represented by the Administrator of the 
% National Aeronautics and Space Administration.  No copyright is claimed in the United States 
% under Title 17, U.S. Code. All Other Rights Reserved.
% 
% Author: Joseph M. Howard, NASA
% Revision Date: 2007.08.22     
